==> libfwbuilder_0.10.4.orig.tar.gz: libfwbuilder-0.10.4.orig/src/fwbuilder/InterfacePolicy.cc <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 Vadim Kurland

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: InterfacePolicy.cc,v 1.3 2001/12/19 12:46:49 lord Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#include <fwbuilder/InterfacePolicy.hh>
#include <fwbuilder/XMLTools.hh>
#include <fwbuilder/FWOptions.hh>

using namespace libfwbuilder;
 
const char *InterfacePolicy::TYPENAME={"InterfacePolicy"};

//TODO: move into class or constants
static const char*  rels[]={
    "Src",
    "Dst",
    "Srv",
    "Act",
    "Dir",
    "Opt",
    "Com",
    NULL
};

InterfacePolicy::InterfacePolicy()
{
    remStr("name");
    remStr("comment");

    rule_elements=rels;
}

InterfacePolicy::~InterfacePolicy() {}
 
Rule*   InterfacePolicy::createRule()
{
    Rule      *r;

    r= new PolicyRule();
    r->add( new PolicyRuleOptions() );

    return r;
}

==> libfwbuilder-1.0.2.tar.gz: libfwbuilder-1.0.2/src/fwbuilder/InterfacePolicy.cc <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: InterfacePolicy.cc,v 1.8 2002/09/08 19:28:16 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include <assert.h>

#include <fwbuilder/InterfacePolicy.hh>
#include <fwbuilder/XMLTools.hh>
#include <fwbuilder/FWOptions.hh>
#include <fwbuilder/FWObjectDatabase.hh>

using namespace libfwbuilder;
 
const char *InterfacePolicy::TYPENAME={"InterfacePolicy"};

InterfacePolicy::InterfacePolicy()
{
    remStr("name");
    remStr("comment");
}

InterfacePolicy::InterfacePolicy(const FWObject *root)
{
    remStr("name");
    remStr("comment");
}

InterfacePolicy::~InterfacePolicy() {}
 
Rule*   InterfacePolicy::createRule()
{
    FWObjectDatabase* db=dynamic_cast<FWObjectDatabase*>(getRoot());
    assert(db!=NULL);
    return Rule::cast( db->create(PolicyRule::TYPENAME, true) );
}
